@@ -1136,7 +1136,11 @@ battstat_show_help( ProgressData *battstat, const char *section )
   else
     uri = g_strdup ("help:mate-battstat");
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+  gtk_show_uri_on_window (NULL,
+#else
   gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (battstat->applet)),
+#endif
                 uri,
                 gtk_get_current_event_time (),
                 &error);
@@ -1180,7 +1184,7 @@ about_cb( GtkAction *action, ProgressData *battstat )
    };
 
   char copyright[] = \
-    "Copyright \xc2\xa9 2012-2017 MATE developers\n"
+    "Copyright \xc2\xa9 2012-2016 MATE developers\n"
     "Copyright \xc2\xa9 2002-2005 Free Software Foundation and others\n"
     "Copyright \xc2\xa9 2000 The Gnulix Society";
 
