@@ -107,7 +107,6 @@ static void     cpufreq_applet_get_preferred_width   (GtkWidget *widget,
                                                       gint *natural_width);
 static void     cpufreq_applet_change_orient     (MatePanelApplet        *pa,
                                                   MatePanelAppletOrient   orient);
-static void     cpufreq_applet_style_updated     (GtkWidget *widget);
 static gboolean cpufreq_applet_factory           (CPUFreqApplet      *applet,
                                                   const gchar        *iid,
                                                   gpointer            gdata);
@@ -222,7 +221,6 @@ cpufreq_applet_class_init (CPUFreqAppletClass *klass)
         gobject_class->dispose = cpufreq_applet_dispose;
 
         widget_class->size_allocate = cpufreq_applet_size_allocate;
-        widget_class->style_updated = cpufreq_applet_style_updated;
 	widget_class->get_preferred_width = cpufreq_applet_get_preferred_width;
         widget_class->button_press_event = cpufreq_applet_button_press;
         widget_class->key_press_event = cpufreq_applet_key_press;
@@ -290,24 +288,6 @@ cpufreq_applet_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
         GTK_WIDGET_CLASS (cpufreq_applet_parent_class)->size_allocate (widget, allocation);
 }
 
-static gint
-get_max_text_width (GtkWidget *widget,
-                    const char *text)
-{
-	PangoContext *context;
-	PangoLayout *layout;
-	PangoRectangle logical_rect;
-
-	context = gtk_widget_get_pango_context (widget);
-	layout = pango_layout_new (context);
-	pango_layout_set_text (layout, text, -1);
-	pango_layout_get_pixel_extents (layout, NULL, &logical_rect);
-
-	g_object_unref (layout);
-
-	return logical_rect.width;
-}
-
 static gint
 cpufreq_applet_get_max_label_width (CPUFreqApplet *applet)
 {
@@ -322,6 +302,7 @@ cpufreq_applet_get_max_label_width (CPUFreqApplet *applet)
 
 	available_freqs = cpufreq_monitor_get_available_frequencies (applet->monitor);
 	while (available_freqs) {
+		GtkWidget     *label;
 		gint           label_width;
 		const gchar   *text;
 		gchar         *freq_text;
@@ -331,10 +312,12 @@ cpufreq_applet_get_max_label_width (CPUFreqApplet *applet)
 		freq = atoi (text);
 
 		freq_text = cpufreq_utils_get_frequency_label (freq);
-		label_width = get_max_text_width (applet->label, freq_text);
+		label = gtk_label_new (freq_text);
+		gtk_widget_get_preferred_width (applet->label, &label_width, NULL);
 		width = MAX (width, label_width); 
 
 		g_free (freq_text);
+		gtk_widget_destroy (label);
 
 		available_freqs = g_list_next (available_freqs);
 	}
@@ -347,21 +330,37 @@ cpufreq_applet_get_max_label_width (CPUFreqApplet *applet)
 static gint
 cpufreq_applet_get_max_perc_width (CPUFreqApplet *applet)
 {
+	GtkWidget      *label;
+	gint            width;
+
 	if (applet->max_perc_width > 0)
 		return applet->max_perc_width;
 
-	applet->max_perc_width = get_max_text_width (applet->label, "100%");
+	label = gtk_label_new ("100%");
+	gtk_widget_get_preferred_width (applet->label, &width,&width);
+	applet->max_perc_width = width +20; /*for some reason width always comes up 2 characters*/
+	gtk_widget_destroy (label);
+
 	return applet->max_perc_width;
 }
 
 static gint
 cpufreq_applet_get_max_unit_width (CPUFreqApplet *applet)
 {
+	GtkWidget     *label;
+	gint           w1, w2;
+
 	if (applet->max_unit_width > 0)
 		return applet->max_unit_width;
 
-	applet->max_unit_width = MAX (get_max_text_width (applet->unit_label, "GHz"),
-	                              get_max_text_width (applet->unit_label, "MHz"));
+	label = gtk_label_new ("GHz");
+	gtk_widget_get_preferred_width (applet->label, &w1, NULL);
+
+	gtk_label_set_text (GTK_LABEL (label), "MHz");
+	gtk_widget_get_preferred_width (applet->label, &w2, NULL);
+
+	gtk_widget_destroy (label);
+	applet->max_unit_width = MAX (w1, w2)-1;
 	return applet->max_unit_width;
 }
 
@@ -415,6 +414,8 @@ cpufreq_applet_popup_position_menu (GtkMenu  *menu,
         GtkAllocation   allocation;
         gint            menu_xpos;
         gint            menu_ypos;
+        gint            sc_width;
+        gint            sc_height;
 
         widget = GTK_WIDGET (gdata);
 
@@ -422,7 +423,10 @@ cpufreq_applet_popup_position_menu (GtkMenu  *menu,
 
         gdk_window_get_origin (gtk_widget_get_window (widget), &menu_xpos, &menu_ypos);
 
-	gtk_widget_get_allocation (widget, &allocation);
+        gtk_widget_get_allocation (widget, &allocation);
+
+        gdk_window_get_geometry (gdk_screen_get_root_window (gtk_widget_get_screen (widget)), NULL, NULL,
+                                 &sc_width, &sc_height);
 
         menu_xpos += allocation.x;
         menu_ypos += allocation.y;
@@ -430,14 +434,14 @@ cpufreq_applet_popup_position_menu (GtkMenu  *menu,
         switch (mate_panel_applet_get_orient (MATE_PANEL_APPLET (widget))) {
         case MATE_PANEL_APPLET_ORIENT_DOWN:
         case MATE_PANEL_APPLET_ORIENT_UP:
-                if (menu_ypos > gdk_screen_get_height (gtk_widget_get_screen (widget)) / 2)
+                if (menu_ypos > sc_height / 2)
                         menu_ypos -= requisition.height;
                 else
                         menu_ypos += allocation.height;
                 break;
         case MATE_PANEL_APPLET_ORIENT_RIGHT:
         case MATE_PANEL_APPLET_ORIENT_LEFT:
-                if (menu_xpos > gdk_screen_get_width (gtk_widget_get_screen (widget)) / 2)
+                if (menu_xpos > sc_width / 2)
                         menu_xpos -= requisition.width;
                 else
                         menu_xpos += allocation.width;
@@ -564,20 +568,6 @@ cpufreq_applet_change_orient (MatePanelApplet *pa, MatePanelAppletOrient orient)
         }
 }
 
-static void
-cpufreq_applet_style_updated (GtkWidget *widget)
-{
-        CPUFreqApplet *applet;
-
-        applet = CPUFREQ_APPLET (widget);
-
-        applet->max_label_width = 0;
-        applet->max_unit_width = 0;
-        applet->max_perc_width = 0;
-
-        cpufreq_applet_refresh (applet);
-}
-
 static void
 cpufreq_applet_preferences_cb (GtkAction     *action,
                                CPUFreqApplet *applet)
@@ -592,10 +582,17 @@ cpufreq_applet_help_cb (GtkAction     *action,
 {
         GError *error = NULL;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+	gtk_show_uri_on_window (NULL,
+	                        "help:mate-cpufreq-applet",
+	                        gtk_get_current_event_time (),
+	                        &error);
+#else
 	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
-			"help:mate-cpufreq-applet",
-			gtk_get_current_event_time (),
-			&error);
+	              "help:mate-cpufreq-applet",
+	              gtk_get_current_event_time (),
+	              &error);
+#endif
 
         if (error) {
                 cpufreq_utils_display_error (_("Could not open help document"),
@@ -609,7 +606,7 @@ cpufreq_applet_about_cb (GtkAction     *action,
                          CPUFreqApplet *applet)
 {
         char copyright[] = \
-                "Copyright \xc2\xa9 2012-2017 MATE developers\n"
+                "Copyright \xc2\xa9 2012-2016 MATE developers\n"
                 "Copyright \xC2\xA9 2004 Carlos Garcia Campos";
 
         static const gchar *const authors[] = {
