@@ -121,11 +121,12 @@ drive_button_new (GVolume *volume)
     DriveButton *self;
 
     self = g_object_new (DRIVE_TYPE_BUTTON, NULL);
-    drive_button_set_volume (self, volume);
-    
-    g_signal_connect (gtk_icon_theme_get_default (),
-        "changed", G_CALLBACK (drive_button_theme_change),
-        self);  
+    if (volume != NULL) {
+      drive_button_set_volume (self, volume);
+      g_signal_connect (gtk_icon_theme_get_default (),
+          "changed", G_CALLBACK (drive_button_theme_change),
+          self);
+    }
 
     return (GtkWidget *)self;
 }
@@ -137,10 +138,10 @@ drive_button_new_from_mount (GMount *mount)
 
     self = g_object_new (DRIVE_TYPE_BUTTON, NULL);
     drive_button_set_mount (self, mount);
-    
+
     g_signal_connect (gtk_icon_theme_get_default (),
         "changed", G_CALLBACK (drive_button_theme_change),
-        self);      
+        self);
 
     return (GtkWidget *)self;
 }
@@ -175,6 +176,25 @@ drive_button_unrealize (GtkWidget *widget)
 }
 #endif /* 0 */
 
+#if GTK_CHECK_VERSION(3, 22, 0)
+static int
+_gtk_get_monitor_num (GdkMonitor *monitor)
+{
+    GdkDisplay *display;
+    int n_monitors, i;
+
+    display = gdk_monitor_get_display(monitor);
+    n_monitors = gdk_display_get_n_monitors(display);
+
+    for(i = 0; i < n_monitors; i++)
+    {
+        if(gdk_display_get_monitor(display, i) == monitor) return i;
+    }
+
+    return -1;
+}
+#endif
+
 /* the following function is adapted from gtkmenuitem.c */
 static void
 position_menu (GtkMenu *menu, gint *x, gint *y,
@@ -187,7 +207,12 @@ position_menu (GtkMenu *menu, gint *x, gint *y,
     GtkRequisition requisition;
     GtkTextDirection direction;
     GdkRectangle monitor;
+#if GTK_CHECK_VERSION (3, 22, 0)
+    GdkMonitor *monitor_num;
+    GdkDisplay *display;
+#else
     gint monitor_num;
+#endif
 
     g_return_if_fail (menu != NULL);
     g_return_if_fail (x != NULL);
@@ -202,9 +227,17 @@ position_menu (GtkMenu *menu, gint *x, gint *y,
     theight = requisition.height;
 
     screen = gtk_widget_get_screen (GTK_WIDGET (menu));
+#if GTK_CHECK_VERSION (3, 22, 0)
+    display =gdk_screen_get_display (screen);
+    monitor_num = gdk_display_get_monitor_at_window (display, gtk_widget_get_window (widget));
+    if (monitor_num == NULL)
+        monitor_num = gdk_display_get_monitor (display, 0);
+    gdk_monitor_get_geometry (monitor_num, &monitor);
+#else
     monitor_num = gdk_screen_get_monitor_at_window (screen, gtk_widget_get_window (widget));
     if (monitor_num < 0) monitor_num = 0;
     gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
+#endif
 
     if (!gdk_window_get_origin (gtk_widget_get_window (widget), &tx, &ty)) {
 	g_warning ("Menu not on screen");
@@ -229,7 +262,12 @@ position_menu (GtkMenu *menu, gint *x, gint *y,
 
     *x = CLAMP (tx, monitor.x, MAX (monitor.x, monitor.x + monitor.width - twidth));
     *y = ty;
+
+#if GTK_CHECK_VERSION (3, 22, 0)
+    gtk_menu_set_monitor (menu, _gtk_get_monitor_num (monitor_num));
+#else
     gtk_menu_set_monitor (menu, monitor_num);
+#endif
 }
 
 static gboolean
@@ -329,6 +367,7 @@ drive_button_update (gpointer user_data)
     GIcon *icon;
     int width, height;
     GdkPixbuf *pixbuf = NULL, *scaled;
+    GdkPixbuf *tmp_pixbuf = NULL;
     GtkRequisition button_req, image_req;
     char *display_name, *tip;
 
@@ -336,73 +375,150 @@ drive_button_update (gpointer user_data)
     self = DRIVE_BUTTON (user_data);
     self->update_tag = 0;
 
+    /* base the icon size on the desired button size */
     drive_button_reset_popup (self);
+    gtk_widget_get_preferred_size (GTK_WIDGET (self), NULL, &button_req);
+    gtk_widget_get_preferred_size (gtk_bin_get_child (GTK_BIN (self)), NULL, &image_req);
+    width = self->icon_size - (button_req.width - image_req.width);
+    height = self->icon_size - (button_req.height - image_req.height);
 
-    /* if no volume or mount, unset image */
-    if (!self->volume && !self->mount) {
-	if (gtk_bin_get_child (GTK_BIN (self)) != NULL)
-	    gtk_image_set_from_pixbuf (GTK_IMAGE (gtk_bin_get_child (GTK_BIN (self))), NULL);
-	return FALSE;
+    /* if no volume or mount, display general image */
+    if (!self->volume && !self->mount)
+    {
+        gtk_widget_set_tooltip_text (GTK_WIDGET (self), "nothing to mount");
+        screen = gtk_widget_get_screen (GTK_WIDGET (self));
+        icon_theme = gtk_icon_theme_get_for_screen (screen); //m
+        // note - other good icon would be emblem-unreadable
+        icon_info = gtk_icon_theme_lookup_icon (icon_theme, "media-floppy",
+                                                MIN (width, height),
+                                                GTK_ICON_LOOKUP_USE_BUILTIN);
+        if (icon_info) {
+            pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
+            g_object_unref (icon_info);
+        }
+
+        if (!pixbuf)
+            return FALSE;
+        scaled = gdk_pixbuf_scale_simple (pixbuf, width, height, GDK_INTERP_BILINEAR);
+        if (scaled) {
+            g_object_unref (pixbuf);
+            pixbuf = scaled;
+        }
+        if (gtk_bin_get_child (GTK_BIN (self)) != NULL)
+            gtk_image_set_from_pixbuf (GTK_IMAGE (gtk_bin_get_child (GTK_BIN (self))), pixbuf);
+        return FALSE;
     }
 
-    if (self->volume) {
-	GMount *mount;
+    gboolean is_mounted = FALSE;
 
-	display_name = g_volume_get_name (self->volume);
-	mount = g_volume_get_mount (self->volume);
+    if (self->volume)
+    {
+        GMount *mount;
 
-	if (mount)
-	    tip = g_strdup_printf ("%s\n%s", display_name, _("(mounted)"));
-	else
-	    tip = g_strdup_printf ("%s\n%s", display_name, _("(not mounted)"));
+        display_name = g_volume_get_name (self->volume);
+        mount = g_volume_get_mount (self->volume);
 
-	if (mount)
-	    icon = g_mount_get_icon (mount);
-	else
-	    icon = g_volume_get_icon (self->volume);
+        if (mount)
+        {
+            is_mounted = TRUE;
+            tip = g_strdup_printf ("%s\n%s", display_name, _("(mounted)"));
+        }
+        else
+        {
+            is_mounted = FALSE;
+            tip = g_strdup_printf ("%s\n%s", display_name, _("(not mounted)"));
+        }
+        if (mount)
+            icon = g_mount_get_icon (mount);
+        else
+            icon = g_volume_get_icon (self->volume);
 
-	if (mount)
-	    g_object_unref (mount);
-    } else {
-	display_name = g_mount_get_name (self->mount);
-	tip = g_strdup_printf ("%s\n%s", display_name, _("(mounted)"));
-	icon = g_mount_get_icon (self->mount);
+        if (mount)
+            g_object_unref (mount);
+    } else
+    {
+        is_mounted = TRUE;
+        display_name = g_mount_get_name (self->mount);
+        tip = g_strdup_printf ("%s\n%s", display_name, _("(mounted)"));
+        icon = g_mount_get_icon (self->mount);
     }
 
     gtk_widget_set_tooltip_text (GTK_WIDGET (self), tip);
     g_free (tip);
     g_free (display_name);
 
-    /* base the icon size on the desired button size */
-    gtk_widget_get_preferred_size (GTK_WIDGET (self), NULL, &button_req);
-    gtk_widget_get_preferred_size (gtk_bin_get_child (GTK_BIN (self)), NULL, &image_req);
-    width = self->icon_size - (button_req.width - image_req.width);
-    height = self->icon_size - (button_req.height - image_req.height);
-
     screen = gtk_widget_get_screen (GTK_WIDGET (self));
     icon_theme = gtk_icon_theme_get_for_screen (screen);
     icon_info = gtk_icon_theme_lookup_by_gicon (icon_theme, icon,
-    						MIN (width, height),
-    						GTK_ICON_LOOKUP_USE_BUILTIN);
+                                               MIN (width, height),
+                                               GTK_ICON_LOOKUP_USE_BUILTIN);
     if (icon_info)
     {
-	pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
-	g_object_unref (icon_info);
+        pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
+        g_object_unref (icon_info);
     }
 
     g_object_unref (icon);
 
     if (!pixbuf)
-	return FALSE;
+        return FALSE;
 
-    scaled = gdk_pixbuf_scale_simple (pixbuf, width, height, GDK_INTERP_BILINEAR);
-    if (scaled) {
-	g_object_unref (pixbuf);
-	pixbuf = scaled;
+    // make a copy of pixbuf becasue icon image can be shared by system
+    tmp_pixbuf = gdk_pixbuf_copy (pixbuf);
+    g_object_unref (pixbuf);
+    g_assert (tmp_pixbuf != NULL);
+
+    // if mounted, change icon
+    if (is_mounted)
+    {
+        int icon_width, icon_height, rowstride, n_channels, x, y;
+        guchar *pixels, *p;
+
+        n_channels = gdk_pixbuf_get_n_channels (tmp_pixbuf);
+        g_assert (gdk_pixbuf_get_colorspace (tmp_pixbuf) == GDK_COLORSPACE_RGB);
+        g_assert (gdk_pixbuf_get_bits_per_sample (tmp_pixbuf) == 8);
+        g_assert (gdk_pixbuf_get_has_alpha (tmp_pixbuf));
+        g_assert (n_channels == 4);
+        icon_width = gdk_pixbuf_get_width (tmp_pixbuf);
+        icon_height = gdk_pixbuf_get_height (tmp_pixbuf);
+
+        rowstride = gdk_pixbuf_get_rowstride (tmp_pixbuf);
+        pixels = gdk_pixbuf_get_pixels (tmp_pixbuf);
+
+        GdkRGBA color;
+        gchar *color_string = g_settings_get_string (settings, "drivemount-checkmark-color");
+        if (!color_string)
+                color_string = g_strdup ("#00ff00");
+        gdk_rgba_parse (&color, color_string);
+        g_free (color_string);
+
+        guchar red = color.red*255;
+        guchar green = color.green*255;
+        guchar blue = color.blue*255;
+
+        const gdouble ratio = 0.65;
+        gdouble y_start = icon_height * ratio;
+        gdouble x_start = icon_height * (1 + ratio);
+
+        for (y = y_start; y < icon_height; y++)
+            for (x = x_start - y; x < icon_width; x++)
+            {
+                p = pixels + y * rowstride + x * n_channels;
+                p[0] = red;
+                p[1] = green;
+                p[2] = blue;
+                p[3] = 255;
+            }
     }
 
-    gtk_image_set_from_pixbuf (GTK_IMAGE (gtk_bin_get_child (GTK_BIN (self))), pixbuf);
-    g_object_unref (pixbuf);
+    scaled = gdk_pixbuf_scale_simple (tmp_pixbuf, width, height, GDK_INTERP_BILINEAR);
+    if (scaled) {
+        g_object_unref (tmp_pixbuf);
+        tmp_pixbuf = scaled;
+    }
+
+    gtk_image_set_from_pixbuf (GTK_IMAGE (gtk_bin_get_child (GTK_BIN (self))), tmp_pixbuf);
+    g_object_unref (tmp_pixbuf);
 
     gtk_widget_get_preferred_size (GTK_WIDGET (self), NULL, &button_req);
 
@@ -657,11 +773,11 @@ gvm_check_dvd_only (const char *udi, const char *device, const char *mount_point
 {
 	char *path;
 	gboolean retval;
-	
+
 	path = g_build_path (G_DIR_SEPARATOR_S, mount_point, "video_ts", NULL);
 	retval = g_file_test (path, G_FILE_TEST_IS_DIR);
 	g_free (path);
-	
+
 	/* try the other name, if needed */
 	if (retval == FALSE) {
 		path = g_build_path (G_DIR_SEPARATOR_S, mount_point,
@@ -669,7 +785,7 @@ gvm_check_dvd_only (const char *udi, const char *device, const char *mount_point
 		retval = g_file_test (path, G_FILE_TEST_IS_DIR);
 		g_free (path);
 	}
-	
+
 	return retval;
 }
 /* END copied from mate-volume-manager/src/manager.c */
@@ -691,7 +807,7 @@ check_dvd_video (DriveButton *self)
 
 	file = g_mount_get_root (mount);
 	g_object_unref (mount);
-	
+
 	if (!file)
 		return FALSE;
 
@@ -869,20 +985,24 @@ drive_button_ensure_popup (DriveButton *self)
     mounted = FALSE;
 
     if (self->volume) {
-	GMount *mount = NULL;
+		GMount *mount = NULL;
 
-	display_name = g_volume_get_name (self->volume);
-	ejectable = g_volume_can_eject (self->volume);
+		display_name = g_volume_get_name (self->volume);
+		ejectable = g_volume_can_eject (self->volume);
 
-	mount = g_volume_get_mount (self->volume);
-	if (mount) {
-	    mounted = TRUE;
-	    g_object_unref (mount);
-	}
+		mount = g_volume_get_mount (self->volume);
+		if (mount) {
+		    mounted = TRUE;
+		    g_object_unref (mount);
+		}
     } else {
-	display_name = g_mount_get_name (self->mount);
-	ejectable = g_mount_can_eject (self->mount);
-	mounted = TRUE;
+    	if (!G_IS_MOUNT(self->volume))
+    		return;
+		else {
+			display_name = g_mount_get_name (self->mount);
+			ejectable = g_mount_can_eject (self->mount);
+			mounted = TRUE;
+		}
     }
 
     self->popup_menu = gtk_menu_new ();
