@@ -46,6 +46,8 @@ struct _DriveList
     GtkOrientation orientation;
     guint layout_tag;
     GtkReliefStyle relief;
+    GtkWidget *dummy;
+    gint count;
 
     int icon_size;
 };
@@ -63,5 +65,6 @@ void       drive_list_set_panel_size  (DriveList *list,
 				       int panel_size);
 void       drive_list_set_transparent (DriveList *self,
 				       gboolean transparent);
+GSettings *settings;
 
 #endif /* DRIVE_LIST_H */
