@@ -53,10 +53,17 @@ static void help_cb (GtkAction      *action,
 {
     GError *error = NULL;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+    gtk_show_uri_on_window (NULL,
+                            "help:mateweather",
+                            gtk_get_current_event_time (),
+                            &error);
+#else
     gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)),
-		"help:mateweather",
-		gtk_get_current_event_time (),
-		&error);
+                  "help:mateweather",
+                  gtk_get_current_event_time (),
+                  &error);
+#endif
 
     if (error) { 
 	GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
@@ -451,7 +458,8 @@ update_finish (WeatherInfo *info, gpointer data)
 	    place_widgets(gw_applet);
 
 #ifdef HAVE_LIBNOTIFY
-        if (gw_applet->mateweather_pref.show_notifications)
+        if (gw_applet->mateweather_pref.show_notifications &&
+            !weather_info_equal(gw_applet->mateweather_previnfo, gw_applet->mateweather_info))
         {
 		    NotifyNotification *n;
 	            
@@ -491,6 +499,9 @@ update_finish (WeatherInfo *info, gpointer data)
 		   	 g_free (detail);
 		    }
         }
+
+        weather_info_free (gw_applet->mateweather_previnfo);
+        gw_applet->mateweather_previnfo = weather_info_clone (gw_applet->mateweather_info);
 #endif
     }
     else
@@ -542,9 +553,11 @@ void mateweather_update (MateWeatherApplet *gw_applet)
 	weather_info_update(gw_applet->mateweather_info, &prefs,
 			    update_finish, gw_applet);
     } else {
+        weather_info_abort (gw_applet->mateweather_info);
         weather_info_free(gw_applet->mateweather_info);
         gw_applet->mateweather_info = weather_info_new(gw_applet->mateweather_pref.location,
 						    &prefs,
 						    update_finish, gw_applet);
     }
+
 }
