@@ -292,9 +292,6 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 
 	g_object_unref(builder);
 
-	g_signal_connect_after (note->w_body, "button-press-event",
-	                        G_CALLBACK (gtk_true), note);
-
 	g_signal_connect (gtk_text_view_get_buffer(GTK_TEXT_VIEW(note->w_body)),
 			  "changed",
 			  G_CALLBACK (buffer_changed), note);
@@ -378,10 +375,17 @@ static void
 response_cb (GtkWidget *dialog, gint id, gpointer data)
 {
         if (id == GTK_RESPONSE_HELP)
+#if GTK_CHECK_VERSION (3, 22, 0)
+		gtk_show_uri_on_window (GTK_WINDOW (dialog),
+		                        "help:mate-stickynotes-applet/stickynotes-settings-individual",
+		                        gtk_get_current_event_time (),
+		                        NULL);
+#else
 		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
-				"help:mate-stickynotes-applet/stickynotes-settings-individual",
-				gtk_get_current_event_time (),
-				NULL);
+		              "help:mate-stickynotes-applet/stickynotes-settings-individual",
+		              gtk_get_current_event_time (),
+		              NULL);
+#endif
         else if (id == GTK_RESPONSE_CLOSE)
                 gtk_widget_hide (dialog);
 }
