@@ -335,10 +335,17 @@ void menu_preferences_cb(GtkAction *action, StickyNotesApplet *applet)
 void menu_help_cb(GtkAction *action, StickyNotesApplet *applet)
 {
 	GError *error = NULL;
+#if GTK_CHECK_VERSION (3, 22, 0)
+	gtk_show_uri_on_window (NULL,
+	                        "help:mate-stickynotes-applet",
+	                        gtk_get_current_event_time (),
+	                        &error);
+#else
 	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet->w_applet)),
-			"help:mate-stickynotes-applet",
-			gtk_get_current_event_time (),
-			&error);
+	              "help:mate-stickynotes-applet",
+	              gtk_get_current_event_time (),
+	              &error);
+#endif
 	if (error) {
 		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 							   _("There was an error displaying help: %s"), error->message);
@@ -362,7 +369,7 @@ menu_about_cb (GtkAction *action,
 	};
 
 	char copyright[] = \
-		"Copyright \xc2\xa9 2012-2017 MATE developers\n"
+		"Copyright \xc2\xa9 2012-2016 MATE developers\n"
 		"Copyright \xc2\xa9 2005 Davyd Madeley\n"
 		"Copyright \xc2\xa9 2002-2003 Loban A Rahman";
 
@@ -524,10 +531,17 @@ void preferences_response_cb(GtkWidget *dialog, gint response, gpointer data)
 {
 	if (response == GTK_RESPONSE_HELP) {
 		GError *error = NULL;
+#if GTK_CHECK_VERSION (3, 22, 0)
+		gtk_show_uri_on_window (GTK_WINDOW (dialog),
+		                        "help:mate-stickynotes-applet/stickynotes-advanced-settings",
+		                        gtk_get_current_event_time (),
+		                        &error);
+#else
 		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
-				"help:mate-stickynotes-applet/stickynotes-advanced-settings",
-				gtk_get_current_event_time (),
-				&error);
+		              "help:mate-stickynotes-applet/stickynotes-advanced-settings",
+		              gtk_get_current_event_time (),
+		              &error);
+#endif
 		if (error) {
 			dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 								   _("There was an error displaying help: %s"), error->message);
